@@ -16,9 +16,8 @@
 #    more: https://github.com/manatlan/guy
 # #############################################################################
 
-__version__="0.0.3"
+__version__="0.0.9"
 
-from .gtag import GTag,GTagApp,ReactiveMethod,ReactiveProp,bind,State
-from .tag import Tag
+from .gtag import GTag,bind,Tag
 
-__all__ = ['GTag', 'bind', 'State']
\ No newline at end of file
+__all__ = ['GTag', 'bind', 'Tag' ]
